===============================
dbaas laas
===============================

.. image:: https://badge.fury.io/py/dbaas-laas.png
    :target: http://badge.fury.io/py/dbaas-laas

.. image:: https://travis-ci.org/ricardosdias/dbaas-laas.png?branch=master
        :target: https://travis-ci.org/ricardosdias/dbaas-laas

.. image:: https://pypip.in/d/dbaas-laas/badge.png
        :target: https://pypi.python.org/pypi/dbaas-laas


Python dbaas laas template

* Free software: BSD license
* Documentation: https://dbaas-laas.readthedocs.org.

Features
--------

* TODO